@@ -95,7 +95,13 @@ def request(kw, step):
     expected = step['expected']
     expected['status_code'] = expected.get('status_code', None)
     expected['text'] = expected.get('text', None)
-    expected['json'] = json2dict(expected.get('json', '{}'))
+    json_str = expected.get('json', '{}')
+    if json_str[0] == '[':
+        index = json_str.split(']')[0][1:]
+        expected['json'] = json2dict(json_str[len(index) + 2:])
+        expected['json_index'] = int(index)
+    else:
+        expected['json'] = json2dict(expected.get('json', '{}'))
     expected['cookies'] = json2dict(expected.get('cookies', '{}'))
     expected['headers'] = json2dict(expected.get('headers', '{}'))
     timeout = float(expected.get('timeout', 10))
@@ -226,7 +232,10 @@ def request(kw, step):
             logger.info('cookies var: %s' % (repr(result['var'])))
 
     if expected['json']:
-        result = check(expected['json'], response['json'])
+        if 'json_index' in expected:
+            result = check(expected['json'], response['json'][expected['json_index']])
+        else:
+            result = check(expected['json'], response['json'])
         logger.info('json check result: %s' % result)
         if result['code'] != 0:
             raise Exception(
